@@ -2,7 +2,7 @@ package Dancer2::Session::CGISession;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moo;
 use Carp;
@@ -83,6 +83,9 @@ sub _flush {
     my ( $class, $id, $data ) = @_;
 
     my $cgi_session = $class->get_cgi_session( $id );
+    foreach my $key (keys %{$data} ){
+        delete $$data{$key} if ($key =~ m/^_SESSION_/);
+    }
     $cgi_session->param( %{$data} );
     $cgi_session->flush;
 }
@@ -133,6 +136,10 @@ You can set CGI::Session drivers and parameters using Dancer2 configuration
 
 Pierre VIGIER E<lt>pierre.vigier@gmail.comE<gt>
 
+=head2 Contributors
+
+jwilliams99 E<lt>https://github.com/jwilliams99E<gt>
+
 =head1 COPYRIGHT
 
 Copyright 2015- Pierre VIGIER
